"use client";

import moment from "moment-timezone";
import Image from "next/image";
import { Dispatch, SetStateAction, useState } from "react";
import { useTimer } from "react-timer-hook";
import useSWR from "swr";

import "moment/locale/id";
moment.locale("id");

export default function Home() {
  const [modalOpen, setModalOpen] = useState(false);
  const [modalIndex, setModalIndex] = useState(0);
  const [prediksi, setPrediksi] = useState(null);

  return (
    <main className="mx-8 md:mx-48 mb-40">
      <Result
        prediksi={prediksi}
        modalOpen={modalOpen}
        setModalOpen={setModalOpen}
        setModalIndex={setModalIndex}
      />
      <Prediksi setPrediksi={setPrediksi} />
      {modalOpen && (
        <BBFS
          prediksi={prediksi}
          modalIndex={modalIndex}
          modalOpen={modalOpen}
          setModalOpen={setModalOpen}
        />
      )}
    </main>
  );
}

function Prediksi({
  setPrediksi,
}: {
  setPrediksi: Dispatch<SetStateAction<any>>;
}) {
  const { data } = useSWR("getPrediksi", {
    fetcher: async () => {
      const res = await fetch("https://prediksimantapwd.com/api/prediksi");
      return await res.json();
    },
    revalidateOnFocus: false,
    revalidateOnReconnect: false,
    refreshWhenOffline: false,
    refreshWhenHidden: false,
    refreshInterval: 0,
  });

  setPrediksi(data);
  return <div />;
}

function Result({
  prediksi,
  modalOpen,
  setModalOpen,
  setModalIndex,
}: {
  prediksi: any;
  modalOpen: boolean;
  setModalOpen: Dispatch<SetStateAction<boolean>>;
  setModalIndex: Dispatch<SetStateAction<number>>;
}) {
  const { data, error } = useSWR("getResult", {
    fetcher: async () => {
      const url =
        "https://corsproxy.org/?" +
        encodeURIComponent(
          "https://mantapwd.com/office/game-oc/game/getNodeInfoList?l=id&parentId=170969",
        );
      const res = await fetch(url);
      return await res.json();
    },
    revalidateOnFocus: false,
    revalidateOnReconnect: false,
    refreshWhenOffline: false,
    refreshWhenHidden: false,
    refreshInterval: 0,
  });

  if (error) return <div className="mt-6 text-xl">Error...</div>;
  if (!data) return <div className="mt-6 text-xl">Loading...</div>;
  if (data.error) return <div className="mt-6 text-xl">Maintenance...</div>;

  return (
    <div className="grid grid-cols-1 lg:grid-cols-2 xl:grid-cols-3 2xl:grid-cols-4 gap-8 mt-12">
      {data.result.map((item: any) => (
        <div
          key={item.id}
          className="rounded bg-black border border-custom p-6 md:p-8"
        >
          <Image
            className=""
            src={
              prediksi.find(
                (obj: any) =>
                  obj.pasaran === item.lotteryNodeFetchOutDto.gameName,
              ).image
            }
            width={384}
            height={226}
            alt="logo"
          />
          <div className="font-bold text-xl md:text-2xl text-center">
            {item.lotteryNodeFetchOutDto.gameName}
          </div>
          <div className="grid grid-cols-2 gap-2 mt-6">
            <div className="text-center">
              <p className="text-custom font-semibold">Prediksi</p>
              <p className="text-xs">
                {moment(item.lotteryNodeFetchOutDto.serverNowTime).format(
                  "dddd, DD MMMM YYYY",
                )}
              </p>
            </div>
            <div className="text-center">
              <p className="text-custom font-semibold">Result</p>
              <p className="text-xs">
                <Countdown
                  expiryTimestamp={moment
                    .tz(
                      item.lotteryNodeFetchOutDto.lotteryStopTime,
                      "Asia/Jakarta",
                    )
                    .local()}
                />
              </p>
            </div>
          </div>
          <div className="grid grid-cols-2 gap-2 my-4">
            <button
              className="bg-black hover:bg-custom border border-custom text-center font-bold py-1 px-2 rounded"
              onClick={() => {
                setModalIndex(
                  prediksi.find(
                    (obj: any) =>
                      obj.pasaran === item.lotteryNodeFetchOutDto.gameName,
                  ).index,
                );
                setModalOpen(!modalOpen);
              }}
            >
              PREDIKSI
            </button>
            <div
              className={
                item.lotteryNodeFetchOutDto.gameStatus === "1"
                  ? "rounded bg-custom text-black p-2"
                  : "rounded bg-red-600 text-white p-2"
              }
            >
              <div className="font-bold text-2xl text-center">
                {item.lotteryNodeFetchOutDto.volatility.slice(0, 4)}
              </div>
            </div>
          </div>
          <div className="grid grid-cols-2 gap-2">
            <a
              className="bg-black hover:bg-custom border border-custom text-center font-bold py-1 px-2 rounded"
              href="https://mantapwd888.com/#/register"
              target="_blank"
            >
              DAFTAR
            </a>
            <a
              className="bg-black hover:bg-custom border border-custom text-center font-bold py-1 px-2 rounded"
              href="https://mantapwd888.com"
              target="_blank"
            >
              LOGIN
            </a>
          </div>
        </div>
      ))}
    </div>
  );
}

function BBFS({
  prediksi,
  modalIndex,
  modalOpen,
  setModalOpen,
}: {
  prediksi: any;
  modalIndex: number;
  modalOpen: boolean;
  setModalOpen: Dispatch<SetStateAction<boolean>>;
}) {
  return (
    <div className="relative z-10" role="dialog" aria-modal="true">
      <div className="fixed inset-0 z-10 w-screen overflow-y-auto">
        <div
          className="flex min-h-full items-center justify-center p-6 text-xs md:text-sm text-center"
          onClick={() => setModalOpen(!modalOpen)}
        >
          <div
            className="bg-black border border-custom p-6 pb-10 w-96 md:w-1/4"
            onClick={(e) => e.stopPropagation()}
          >
            <div className="relative">
              <button
                type="button"
                className="bg-custom px-2 py-2 absolute -right-6 -top-6"
                onClick={() => setModalOpen(!modalOpen)}
              >
                <svg
                  className="w-2 h-2"
                  aria-hidden="true"
                  xmlns="http://www.w3.org/2000/svg"
                  fill="none"
                  viewBox="0 0 14 14"
                >
                  <path
                    stroke="black"
                    stroke-linecap="round"
                    stroke-linejoin="round"
                    stroke-width="2"
                    d="m1 1 6 6m0 0 6 6M7 7l6-6M7 7l-6 6"
                  />
                </svg>
              </button>
            </div>

            <Image
              className="mx-auto mt-2"
              src="/logo.png"
              width={280}
              height={67}
              alt="logo"
            />

            <div className="grid grid-cols-1 my-6">
              <div className="bg-custom text-black text-center font-bold py-1 px-2">
                {prediksi[modalIndex].pasaran}
              </div>
            </div>

            <div className="bg-custom text-black text-center font-bold py-1 px-2">
              {moment().format("dddd, DD MMMM YYYY")}
            </div>
            <div className="grid grid-cols-2 mb-6">
              <div className="border border-white text-white p-2">
                <div>{prediksi[modalIndex].bet_closed}</div>
              </div>
              <div className="border border-white text-white p-2">
                <div>{prediksi[modalIndex].result}</div>
              </div>
            </div>

            <div className="grid grid-cols-2">
              <div className="border border-white text-white p-2">
                <div>BBFS</div>
              </div>
              <div className="border border-white text-white p-2">
                <div>{prediksi[modalIndex].bbfs}</div>
              </div>
            </div>

            <div className="grid grid-cols-2">
              <div className="border border-white text-white p-2">
                <div>AM</div>
              </div>
              <div className="border border-white text-white p-2">
                <div>{prediksi[modalIndex].am}</div>
              </div>
            </div>

            <div className="grid grid-cols-2">
              <div className="border border-white text-white p-2">
                <div>CB</div>
              </div>
              <div className="border border-white text-white p-2">
                <div>{prediksi[modalIndex].cb.join(" / ")}</div>
              </div>
            </div>

            <div className="grid grid-cols-2">
              <div className="border border-white text-white p-2">
                <div>CM</div>
              </div>
              <div className="border border-white text-white p-2">
                <div>{prediksi[modalIndex].cm.join(" / ")}</div>
              </div>
            </div>

            <div className="grid grid-cols-1 mt-6">
              <div className="bg-custom text-black text-center font-bold py-1 px-2">
                4D TOP
              </div>
            </div>
            <div className="grid grid-cols-3">
              {prediksi[modalIndex].fourd.map((item: any) => {
                return (
                  <div className="border border-white text-white p-2">
                    <div>{item}</div>
                  </div>
                );
              })}
            </div>

            <div className="grid grid-cols-1 mt-6">
              <div className="bg-custom text-black text-center font-bold py-1 px-2">
                2D BB
              </div>
            </div>
            <div className="grid grid-cols-5 grid-rows-2">
              {prediksi[modalIndex].twod.map((item: any) => {
                return (
                  <div className="border border-white text-white p-2">
                    <div>{item}</div>
                  </div>
                );
              })}
            </div>

            <div className="grid grid-cols-1 mt-6">
              <div className="bg-custom text-black text-center font-bold py-1 px-2">
                SHIO
              </div>
            </div>
            <div className="grid grid-cols-3">
              {prediksi[modalIndex].shio.map((item: any) => {
                return (
                  <div className="border border-white text-white p-2">
                    <div>{item}</div>
                  </div>
                );
              })}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
}

function Countdown({ expiryTimestamp }: { expiryTimestamp: any }) {
  const { seconds, minutes, hours, days } = useTimer({
    expiryTimestamp,
  });

  return (
    <div>
      Bet Close - {days > 0 ? <span>{days} hari </span> : ""}
      <span>{String(hours).padStart(2, "0")}</span>:
      <span>{String(minutes).padStart(2, "0")}</span>:
      <span>{String(seconds).padStart(2, "0")}</span>
    </div>
  );
}
